@@ -42,11 +42,11 @@ try:
 except ImportError:
     from pystan.external.scipy.mstats import mquantiles
 
-import pystan.chains as chains
+import pystan.chains
+import pystan._misc
 from pystan.constants import (MAX_UINT, sampling_algo_t, optim_algo_t,
                               sampling_metric_t, stan_args_method_t)
 
-logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger('pystan')
 
 
@@ -139,11 +139,12 @@ def _format_number(num, n_signif_figures, max_width):
     """
     if max_width < 6:
         raise NotImplementedError("Guaranteed formatting in fewer than 6 characters not supported.")
-    n_digits = math.floor(math.log10(abs(num) + 1e-5)) + 1
-    if abs(num) > 10**-n_signif_figures and n_digits <= max_width - n_signif_figures:
+    # add 0.5 to prevent log(0) errors; only affects n_digits calculation for num > 0
+    n_digits = lambda num: math.floor(math.log10(abs(num) + 0.5)) + 1
+    if abs(num) > 10**-n_signif_figures and n_digits(num) <= max_width - n_signif_figures:
         return str(round(num, n_signif_figures))[:max_width].rstrip('.')
     elif _number_width(num) <= max_width:
-        if n_digits >= n_signif_figures:
+        if n_digits(num) >= n_signif_figures:
             # the int() is necessary for consistency between Python 2 and 3
             return str(int(round(num)))
         else:
@@ -310,9 +311,9 @@ def _summary_sim(sim, pars, probs):
     c_quan_names = dict(parameters=np.asarray(sim['fnames_oi'])[tidx_colm],
                         stats=probs_str,
                         chains=tuple("chain:{}".format(cid) for cid in cids))
-    # TODO: include sem, ess and rhat, see rstan/rstan/src/chains.cpp
-    ess = np.array([chains.ess(sim, n) for n in tidx_colm], dtype=int)
-    rhat = np.array([chains.splitrhat(sim, n) for n in tidx_colm])
+    ess_and_rhat = np.array([pystan.chains.ess_and_splitrhat(sim, n) for n in tidx_colm])
+    ess, rhat = [arr.ravel() for arr in np.hsplit(ess_and_rhat, 2)]
+    ess = ess.astype(int)
     return dict(msd=msd, c_msd=c_msd, c_msd_names=c_msd_names, quan=quan,
                 c_quan=c_quan, c_quan_names=c_quan_names,
                 sem=msd[:, 1] / np.sqrt(ess), ess=ess, rhat=rhat,
@@ -818,7 +819,6 @@ def _idx_col2rowm(d):
 
 
 def _get_kept_samples(n, sim):
-    # NOTE: this is in stanfit-class.R in RStan (rather than misc.R)
     """Get samples to be kept from the chain(s) for `n`th parameter.
 
     Samples from different chains are merged.
@@ -835,12 +835,7 @@ def _get_kept_samples(n, sim):
         Samples being kept, permuted and in column-major order.
 
     """
-    ss = []
-    for s, nw, perm in zip(sim['samples'], sim['warmup2'], sim['permutation']):
-        nth_key = list(s['chains'].keys())[n]
-        r = s['chains'][nth_key][nw:]
-        ss.extend(r[perm])
-    return np.asarray(ss)
+    return pystan._misc.get_kept_samples(n, sim)
 
 
 def _get_samples(n, sim, inc_warmup=True):
@@ -859,15 +854,7 @@ def _get_samples(n, sim, inc_warmup=True):
         Each chain is an element in the list.
 
     """
-    if all(w2 == 0 for w2 in sim['warmup2']):
-        # from RStan
-        inc_warmup = True
-    ss = []
-    for s, nw in zip(sim['samples'], sim['warmup2']):
-        nth_key = list(s['chains'].keys())[n]
-        r = s['chains'][nth_key] if inc_warmup else s['chains'][nth_key][nw:]
-        ss.append(np.asarray(r))
-    return ss
+    return pystan._misc.get_samples(n, sim, inc_warmup)
 
 
 def _redirect_stderr():
