@@ -5,6 +5,7 @@
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/softmax.hpp>
 #include <stan/agrad/rev/var.hpp>
+#include <stan/math/error_handling/matrix/check_nonzero_size.hpp>
 
 namespace stan {
   namespace agrad {
@@ -58,7 +59,7 @@ namespace stan {
       using Eigen::Matrix;
       using Eigen::Dynamic;
 
-      stan::math::validate_nonzero_size(alpha,"vector argument to var softmax");
+      stan::math::check_nonzero_size("softmax(%1%)",alpha,"alpha",(double*)0);
 
       vari** alpha_vi_array
         = (vari**) memalloc_.alloc(sizeof(vari*) * alpha.size());
