@@ -3,6 +3,7 @@
 
 #include <sstream>
 #include <stan/math/matrix/Eigen.hpp>
+#include <stan/meta/traits.hpp>
 #include <stan/math/error_handling/dom_err.hpp>
 
 namespace stan {
@@ -11,7 +12,7 @@ namespace stan {
     /**
      * Return <code>true</code> if the specified vector 
      * is sorted into increasing order.
-     * There may be duplicate values.  Otherwise, raise a domain
+     * There may not be duplicate values.  Otherwise, raise a domain
      * error according to the specified policy.
      *
      * @param function
@@ -33,8 +34,8 @@ namespace stan {
       for (size_t n = 1; n < y.size(); n++) {
         if (!(y[n] > y[n-1])) {
           std::ostringstream stream;
-          stream << name << " is not a valid ordered vector."
-                 << " The element at " << n 
+          stream << " is not a valid ordered vector."
+                 << " The element at " << stan::error_index::value + n 
                  << " is %1%, but should be greater than the previous element, "
                  << y[n-1];
           std::string msg(stream.str());
