@@ -4,8 +4,8 @@
 #include <boost/utility/enable_if.hpp>
 #include <boost/type_traits.hpp>
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace math {
@@ -18,10 +18,12 @@ namespace stan {
                         const Eigen::Matrix<double,RA,CA> &A,
                         const Eigen::Matrix<double,RB,CB> &B)
     {
-      validate_square(A,"trace_gen_quad_form");
-      validate_square(D,"trace_gen_quad_form");
-      validate_multiplicable(A,B,"trace_gen_quad_form");
-      validate_multiplicable(B,D,"trace_gen_quad_form");
+      stan::math::check_square("trace_gen_quad_form(%1%)",A,"A",(double*)0);
+      stan::math::check_square("trace_gen_quad_form(%1%)",D,"D",(double*)0);
+      stan::math::check_multiplicable("trace_gen_quad_form(%1%)",A,"A",
+                                      B,"B",(double*)0);
+      stan::math::check_multiplicable("trace_gen_quad_form(%1%)",B,"B",
+                                      D,"D",(double*)0);
       return (D*B.transpose()*A*B).trace();
     }
   }
