@@ -2,7 +2,7 @@
 #define __STAN__MATH__REP_MATRIX_HPP__
 
 #include <boost/math/tools/promotion.hpp>
-#include <stan/math/validate_non_negative_rep.hpp>
+#include <stan/math/error_handling/check_nonnegative.hpp>
 #include <stan/math/matrix/Eigen.hpp>
 
 namespace stan {
@@ -14,8 +14,8 @@ namespace stan {
     Eigen::Matrix<typename boost::math::tools::promote_args<T>::type,
                   Eigen::Dynamic,Eigen::Dynamic>
     rep_matrix(const T& x, int m, int n) {
-      validate_non_negative_rep(m,"rep_matrix rows");
-      validate_non_negative_rep(n,"rep_matrix cols");
+      check_nonnegative("rep_matrix(%1%)", m,"rows", (double*)0);
+      check_nonnegative("rep_matrix(%1%)", n,"cols", (double*)0);
       return Eigen::Matrix<typename boost::math::tools::promote_args<T>::type,
                            Eigen::Dynamic,Eigen::Dynamic>::Constant(m,n,x);
     }
@@ -23,7 +23,7 @@ namespace stan {
     template <typename T>
     inline Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
     rep_matrix(const Eigen::Matrix<T,Eigen::Dynamic,1>& v, int n) {
-      validate_non_negative_rep(n,"rep_matrix of vector, num rows");
+      check_nonnegative("rep_matrix(%1%)", n,"rows", (double*)0);
       Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> result(v.size(),n);
       result.colwise() = v;
       return result;
@@ -32,7 +32,7 @@ namespace stan {
     template <typename T>
     inline Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
     rep_matrix(const Eigen::Matrix<T,1,Eigen::Dynamic>& rv, int m) {
-      validate_non_negative_rep(m,"rep_matrix of row vector, num cols");
+      check_nonnegative("rep_matrix(%1%)", m,"cols", (double*)0);
       Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> result(m,rv.size());
       result.rowwise() = rv;
       return result;
