@@ -40,21 +40,16 @@ namespace stan {
       double logp(0.0);
       
       // validate args (here done over var, which should be OK)
-      if (!check_not_nan(function, y, "Random variable", &logp))
-        return logp;
-      if (!check_finite(function, y_min, "Scale parameter", &logp))
-        return logp;
-      if (!check_positive(function, y_min, "Scale parameter", &logp))
-        return logp;
-      if (!check_finite(function, alpha, "Shape parameter", &logp))
-        return logp;
-      if (!check_positive(function, alpha, "Shape parameter", &logp))
-        return logp;
-      if (!(check_consistent_sizes(function,
-                                   y,y_min,alpha,
-                                   "Random variable","Scale parameter","Shape parameter",
-                                   &logp)))
-        return logp;
+      check_not_nan(function, y, "Random variable", &logp);
+      check_finite(function, y_min, "Scale parameter", &logp);
+      check_positive(function, y_min, "Scale parameter", &logp);
+      check_finite(function, alpha, "Shape parameter", &logp);
+      check_positive(function, alpha, "Shape parameter", &logp);
+      check_consistent_sizes(function,
+                             y,y_min,alpha,
+                             "Random variable","Scale parameter",
+                             "Shape parameter",
+                             &logp);
 
       // check if no variables are involved and prop-to
       if (!include_summand<propto,T_y,T_scale,T_shape>::value)
@@ -159,22 +154,15 @@ namespace stan {
           
       double P(1.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, y_min, alpha,
-                                   "Random variable", "Scale parameter", 
-                                   "Shape parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_finite(function, y_min, "Scale parameter", &P);
+      check_positive(function, y_min, "Scale parameter", &P);
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_consistent_sizes(function, y, y_min, alpha,
+                             "Random variable", "Scale parameter", 
+                             "Shape parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -263,22 +251,15 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, y_min, alpha,
-                                   "Random variable", "Scale parameter", 
-                                   "Shape parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_finite(function, y_min, "Scale parameter", &P);
+      check_positive(function, y_min, "Scale parameter", &P);
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_consistent_sizes(function, y, y_min, alpha,
+                             "Random variable", "Scale parameter", 
+                             "Shape parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -354,22 +335,15 @@ namespace stan {
           
       double P(0.0);
           
-      if (!check_not_nan(function, y, "Random variable", &P))
-        return P;
-      if (!check_nonnegative(function, y, "Random variable", &P))
-        return P;
-      if (!check_finite(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_positive(function, y_min, "Scale parameter", &P))
-        return P;
-      if (!check_finite(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!check_positive(function, alpha, "Shape parameter", &P))
-        return P;
-      if (!(check_consistent_sizes(function, y, y_min, alpha,
-                                   "Random variable", "Scale parameter", 
-                                   "Shape parameter", &P)))
-        return P;
+      check_not_nan(function, y, "Random variable", &P);
+      check_nonnegative(function, y, "Random variable", &P);
+      check_finite(function, y_min, "Scale parameter", &P);
+      check_positive(function, y_min, "Scale parameter", &P);
+      check_finite(function, alpha, "Shape parameter", &P);
+      check_positive(function, alpha, "Shape parameter", &P);
+      check_consistent_sizes(function, y, y_min, alpha,
+                             "Random variable", "Scale parameter", 
+                             "Shape parameter", &P);
           
       // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
@@ -431,14 +405,10 @@ namespace stan {
       using stan::math::check_finite;
       using stan::math::check_positive;
 
-      if (!check_finite(function, y_min, "Scale parameter"))
-        return 0;
-      if (!check_positive(function, y_min, "Scale parameter"))
-        return 0;
-      if (!check_finite(function, alpha, "Shape parameter"))
-        return 0;
-      if (!check_positive(function, alpha, "Shape parameter"))
-        return 0;
+      check_finite(function, y_min, "Scale parameter", (double*)0);
+      check_positive(function, y_min, "Scale parameter", (double*)0);
+      check_finite(function, alpha, "Shape parameter", (double*)0);
+      check_positive(function, alpha, "Shape parameter", (double*)0);
 
       variate_generator<RNG&, exponential_distribution<> >
         exp_rng(rng, exponential_distribution<>(alpha));
